package cn.bunny.service.controller;

import cn.bunny.common.result.Result;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.core.context.SecurityContext;
import org.springframework.security.core.context.SecurityContextHolder;
import org.springframework.security.core.session.SessionInformation;
import org.springframework.security.core.session.SessionRegistry;
import org.springframework.security.core.userdetails.User;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

@Tag(name = "后台登录管理")
@RestController
@RequestMapping("/")
public class BaseController {
    @Autowired
    private SessionRegistry sessionRegistry;

    @GetMapping()
    public String index() {
        return "欢迎访问";
    }

    @Operation(summary = "Security上下文对象", description = "Security上下文对象")
    @GetMapping("/test/getSecurityHolder")
    public Result<Object> getSecurityHolder() {
        SecurityContext context = SecurityContextHolder.getContext();
        return Result.success(context);
    }

    @Operation(summary = "当前所有登录的用户", description = "当前所有登录的用户")
    @GetMapping("/test/getAllUserLogin")
    public Result<Object> getAllUserLogin() {
        return Result.success(sessionRegistry.getAllPrincipals());
    }

    @Operation(summary = "剔除下线", description = "剔除下线")
    @GetMapping("/test/killOut")
    public Result<Object> killOut(String userId) {
        List<Object> allPrincipals = sessionRegistry.getAllPrincipals();
        for (Object allPrincipal : allPrincipals) {
            // 获取当前所有已经登录session会话：未失效的session
            List<SessionInformation> allSessions = sessionRegistry.getAllSessions(allPrincipal, false);
            User user = (User) allPrincipals;

            // 如果用户名匹配将这个用户下线
            if (user.getUsername().equals(userId)) {
                allSessions.forEach(SessionInformation::expireNow);
            }
        }
        return Result.success();
    }
}
