package cn.bunny.service.controller;

import cn.bunny.common.result.Result;
import cn.bunny.entity.email.EmailSend;
import cn.bunny.service.service.EmailService;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

@RestController
@Tag(name = "发送邮件")
@RequestMapping("/test/mail")
@Slf4j
public class MailController {
    @Autowired
    private EmailService emailService;

    @Operation(summary = "发送简单邮件", description = "发送简单邮件")
    @PostMapping("/send-text")
    public Result<String> sendText(@RequestBody EmailSend emailSend) {
        log.info("发送简单邮件");
        emailService.sendSimpleEmail(emailSend);
        return Result.success();
    }

    @Operation(summary = "发送带附件邮件", description = "发送带附件邮件")
    @PostMapping("send-attachment")
    public Result<String> sendAttachment(@RequestBody EmailSend emailSend) {
        log.info("发送带附件邮件");
        boolean isSuccess = emailService.sendAttachmentEmail(emailSend);
        return isSuccess ? Result.success() : Result.error();
    }

    @Operation(summary = "发送富文本邮件", description = "发送富文本邮件")
    @PostMapping("send-rich")
    public Result<String> sendRich(@RequestBody EmailSend emailSend) {
        log.info("发送富文本邮件");

        boolean isSuccess = emailService.sendRich(emailSend);
        return isSuccess ? Result.success() : Result.error();
    }

    @Operation(summary = "发送带抄送的邮件", description = "发送带抄送的邮件")
    @PostMapping("send-cc")
    public Result<String> sendCC(@RequestBody EmailSend emailSend) {
        log.info("发送带抄送的邮件");
        boolean isSuccess = emailService.sendCC(emailSend);
        return isSuccess ? Result.success() : Result.error();
    }
}
